<p>
    [{{ server.last_updated }}] Server <strong>{{ server.name }}</strong> at
    <strong>{{ server.url }}</strong> returned status code
    <strong>{{ server.status_code }}</strong>.
</p>
<p>
    Returned body:
</p>
<pre>
    <code>
        {{ server.response_body }}
    </code>
</pre>
